@@ -1,3 +1,4 @@
+use super::Iconize;
 use crate::Icon;
 use chrono::Weekday;
 use std::fmt;
@@ -55,21 +56,6 @@ impl DateFormatter {
             self.meridiem = Meridiem::Post;
         }
     }
-
-    pub fn set_icon(&self, icon: &mut Icon) {
-        let night = if self.railway {
-            self.hour >= 20 || self.hour <= 6
-        } else {
-            self.hour >= 8 && self.meridiem == Meridiem::Post
-                || self.hour <= 6 && self.meridiem == Meridiem::Ante
-        };
-
-        if night {
-            icon.set_icon("weather-clear-night-symbolic")
-        } else {
-            icon.set_icon("weather-clear-symbolic")
-        }
-    }
 }
 
 impl fmt::Display for DateFormatter {
@@ -168,6 +154,23 @@ impl fmt::Display for Month {
     }
 }
 
+impl Iconize for DateFormatter {
+    fn set_icon(&self, icon: &mut Icon) {
+        let night = if self.railway {
+            self.hour >= 20 || self.hour <= 6
+        } else {
+            self.hour >= 8 && self.meridiem == Meridiem::Post
+                || self.hour <= 6 && self.meridiem == Meridiem::Ante
+        };
+
+        if night {
+            icon.find_icon("weather-clear-night-symbolic")
+        } else {
+            icon.find_icon("weather-clear-symbolic")
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
