@@ -9,8 +9,6 @@ pub struct Icon {
     theme: String,
     /// The base location of the `icons` directory.
     location: PathBuf,
-    /// The visibility of an icon.
-    visible: bool,
 }
 
 impl Icon {
@@ -27,7 +25,6 @@ impl Icon {
             path: PathBuf::new(),
             theme: String::new(),
             location: base,
-            visible: false,
         }
     }
 
@@ -64,16 +61,14 @@ impl Icon {
         themes
     }
 
-    pub fn set_theme(&mut self, theme: String) {
-        self.theme = theme;
-    }
-
-    pub fn make_visible(&mut self) {
-        self.visible = true;
+    pub fn set_theme(&mut self, theme: Option<String>) {
+        if let Some(t) = theme {
+            self.theme = t;
+        }
     }
 
     pub fn find_icon(&mut self, icon_name: &str) {
-        if !self.visible {
+        if self.theme.is_empty() {
             return;
         }
 
