@@ -1,3 +1,4 @@
+use crate::options::Command;
 use crate::Icon;
 use libmacchina::traits::ReadoutError;
 use notify_rust::Notification;
@@ -35,13 +36,21 @@ impl Notifier {
     }
 
     pub fn set_icon(&mut self, icon: &Icon) {
-        if let Some(str) = icon.get_path().to_str() {
+        let path = icon.get_path();
+
+        if !path.exists() {
+            return;
+        }
+
+        if let Some(str) = path.to_str() {
             self.icon = str.to_string();
         }
     }
 
-    pub fn set_timeout(&mut self, timeout: u32) {
-        self.timeout = timeout;
+    pub fn set_timeout(&mut self, timeout: Option<u32>) {
+        if let Some(t) = timeout {
+            self.timeout = t;
+        }
     }
 
     pub fn get_timeout(&self) -> Timeout {
@@ -92,3 +101,36 @@ impl fmt::Display for Summary {
         }
     }
 }
+
+impl From<&Command> for Summary {
+    fn from(cmd: &Command) -> Self {
+        match cmd {
+            Command::Date {
+                railway: _,
+                timeout: _,
+                icon_theme: _,
+            } => Summary::Date,
+            Command::Uptime {
+                timeout: _,
+                icon_theme: _,
+            } => Summary::Uptime,
+            Command::Memory {
+                timeout: _,
+                icon_theme: _,
+            } => Summary::Memory,
+            Command::Battery {
+                timeout: _,
+                icon_theme: _,
+            } => Summary::Battery,
+            Command::Network {
+                interface: _,
+                timeout: _,
+                icon_theme: _,
+            } => Summary::Network,
+            Command::Backlight {
+                timeout: _,
+                icon_theme: _,
+            } => Summary::Backlight,
+        }
+    }
+}
